# Release Notes for pyrax

2012.12.07 - Added the ability for developers to customize the User-agent string for their applications.

2012.11.26 - Added Cloud Block Storage support. Added the refactored code for Cloud Load Balancers that removes the dependency on the python-cloudlb library.

2012.11.24 - Maintenance fix release 1.0.4b.

2012.11.20 - Improved the handling of CDN calls so they don't fail as often, and are more resilient when they do.

2012.11.06 - Release of the initial beta for pyrax. Supports Cloud Servers, Cloud Files, and Cloud Load Balancers.
